.. image:: https://img.shields.io/pypi/v/Pindo.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/Pindo/
.. image:: https://github.com/Clivern/Pindo/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/Clivern/Pindo/actions/workflows/ci.yml

|

=====
Pindo
=====

    Securely Build and Run Code in Docker.


It supports a broad range of programming languages and versions.


Note
====

This project is created and maintained for Cattle. see https://github.com/Clivern/Cattle
